@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 use Acme::CPANAuthors::Register (
     ACPGUEDES => 'Aureliano Coelho Proença Guedes',
@@ -43,6 +43,7 @@ use Acme::CPANAuthors::Register (
     GABRIEL   => 'Gabriel Vieira',
     GARU      => 'Breno G. de Oliveira',
     GEOJS     => 'Geovanny Junio',
+    GILS      => 'Gil Magno Silva',
     GMPASSOS  => 'Graciliano Monteiro Passos',
     GNUSTAVO  => 'Gustavo Leite de Mendonça Chaves',
     GONCALES  => 'Ítalo Buono Gonçales',
@@ -104,6 +105,10 @@ Acme::CPANAuthors::Brazilian - We are brazilian CPAN authors
 
 Acme::CPANAuthors::Brazilian - Nós somos autores brasileiros no CPAN
 
+=for html
+<a href="http://badge.fury.io/pl/Acme-CPANAuthors-Brazilian"><img src="https://badge.fury.io/pl/Acme-CPANAuthors-Brazilian.svg" alt="CPAN version" height="18"></a>
+<a href="https://travis-ci.org/garu/Acme-CPANAuthors-Brazilian"><img src="https://travis-ci.org/garu/Acme-CPANAuthors-Brazilian.svg?branch=master"></a>
+
 =head1 SYNOPSIS
 
    use Acme::CPANAuthors;
@@ -144,7 +149,7 @@ Breno G. de Oliveira E<lt>garu at cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2014 by Breno G. de Oliveira.
+Copyright (C) 2008-2015 by Breno G. de Oliveira.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
